Tutorials
=========

**These pages are currently under development.** However, the
material so far in place should be usable.

This page contains tutorials for programmers wanting to use the
**resqpy** RESQML application programming interface (API).
RESQML is the standard format for storing subsurface models. The
resqpy API is a Python library providing classes and functions
allowing application code to work with RESQML datasets at a
high level.

Whilst reading through a tutorial, it is recommended
that you have a Python interpreter (or Jupyter notebook) open
in another window, so that code snippets can be cut, pasted and
executed whilst progressing through the material.

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   intro_to_resqml
   getting_started_with_model
   working_with_coord
   high_level_objects
   cellular_grids
   grid_properties
   single_property
   creating_test
